@@ -1,4 +1,4 @@
-// Copyright 2017-2018 Parity Technologies
+// Copyright 2017-2021 Parity Technologies
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -32,6 +32,7 @@ use crate::utils::is_lint_attribute;
 
 mod decode;
 mod encode;
+mod max_encoded_len;
 mod utils;
 mod trait_bounds;
 
@@ -333,3 +334,10 @@ pub fn compact_as_derive(input: proc_macro::TokenStream) -> proc_macro::TokenStr
 
 	wrap_with_dummy_const(input, impl_block)
 }
+
+/// Derive `MaxEncodedLen`.
+#[cfg(feature = "max-encoded-len")]
+#[proc_macro_derive(MaxEncodedLen, attributes(max_encoded_len_mod))]
+pub fn derive_max_encoded_len(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
+	max_encoded_len::derive_max_encoded_len(input)
+}
